Module blaxel.core.client.models.billable_time_metric
=====================================================

Classes
-------

`BillableTimeMetric(billable_time: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>, total_allocation: blaxel.core.client.types.Unset | float = <blaxel.core.client.types.Unset object>)`
:   Billable time metric
    
    Attributes:
        billable_time (Union[Unset, float]): Billable time
        total_allocation (Union[Unset, float]): Total memory allocation in GB-seconds
    
    Method generated by attrs for class BillableTimeMetric.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties: dict[str, typing.Any]`
    :

    `billable_time: blaxel.core.client.types.Unset | float`
    :

    `total_allocation: blaxel.core.client.types.Unset | float`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :